# TOTPEnrollmentAnswer

The contents of the Time-based One-time Password enrollment answer.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_id** | **str** | Unique identifier | [readonly] 
**answer** | **str** | An opaque string used to answer the challenge. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


